Index: content/renderer/renderer_blink_platform_impl.h |
diff --git a/content/renderer/renderer_blink_platform_impl.h b/content/renderer/renderer_blink_platform_impl.h |
index df62a9920d1fd33bb5bd6d3f957c8e6566cebe07..2bbee4c3e154089980e44b6c3234a4c9adf55ad4 100644 |
--- a/content/renderer/renderer_blink_platform_impl.h |
+++ b/content/renderer/renderer_blink_platform_impl.h |
@@ -34,8 +34,6 @@ namespace scheduler { |
class RendererScheduler; |
} |
class WebCanvasCaptureHandler; |
-class WebDeviceMotionData; |
-class WebDeviceOrientationData; |
class WebGraphicsContext3DProvider; |
class WebMediaPlayer; |
class WebMediaRecorderHandler; |
@@ -44,6 +42,11 @@ class WebSecurityOrigin; |
class WebServiceWorkerCacheStorage; |
} |
+namespace device { |
+class MotionData; |
+class OrientationData; |
+} |
+ |
namespace service_manager { |
class InterfaceProvider; |
} |
@@ -217,13 +220,12 @@ class CONTENT_EXPORT RendererBlinkPlatformImpl : public BlinkPlatformImpl { |
// Set a double to return when setDeviceLightListener is invoked. |
static void SetMockDeviceLightDataForTesting(double data); |
- // Set WebDeviceMotionData to return when setDeviceMotionListener is invoked. |
- static void SetMockDeviceMotionDataForTesting( |
- const blink::WebDeviceMotionData& data); |
- // Set WebDeviceOrientationData to return when setDeviceOrientationListener |
+ // Set MotionData to return when setDeviceMotionListener is invoked. |
+ static void SetMockDeviceMotionDataForTesting(const device::MotionData& data); |
+ // Set OrientationData to return when setDeviceOrientationListener |
// is invoked. |
static void SetMockDeviceOrientationDataForTesting( |
- const blink::WebDeviceOrientationData& data); |
+ const device::OrientationData& data); |
WebDatabaseObserverImpl* web_database_observer_impl() { |
return web_database_observer_impl_.get(); |